# arviz-stats

[![Run tests](https://github.com/arviz-devs/arviz-stats/actions/workflows/test.yml/badge.svg)](https://github.com/arviz-devs/arviz-stats/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/arviz-devs/arviz-stats/branch/main/graph/badge.svg?token=95N0B8O005)](https://codecov.io/gh/arviz-devs/arviz-stats)
[![Powered by NumFOCUS](https://img.shields.io/badge/powered%20by-NumFOCUS-orange.svg?style=flat&colorA=E1523D&colorB=007D8A)](https://numfocus.org)

ArviZ computational/numeric features: statistical summaries, diagnostics, model comparison... (once finished).

We are currently working on splitting ArviZ into independent modules.
See https://github.com/arviz-devs/arviz/issues/2088 for more details.
